<template>
  <div class="mobile-device">
    <van-sticky class="containter-sticky">
      <navBar @clickLeft="onClickLeft" :title="title"></navBar>
    </van-sticky>
    <div class="search-box">
      <van-dropdown-menu active-color="#1989fa">
        <van-dropdown-item title="产品" ref="item">
          <van-tree-select :items="treeData" :active-id.sync="treeDataIds" :main-active-index.sync="activeIndex"
            @click-item="onNavClick" />
        </van-dropdown-item>
        <van-dropdown-item title="区域" ref="item">
          <el-tree :node-key="'id'" ref="treeList" :data="regionTreeData" :props="props" :load="loadNode" show-checkbox
            check-strictly @check-change="handleCheckChange">
          </el-tree>
        </van-dropdown-item>
        <van-dropdown-item v-model="params.status" :options="statusList" @change="teamChange" />
      </van-dropdown-menu>
      <van-button icon="filter-o" style="border:0" type="default" @click="seoBtn">筛选
      </van-button>
    </div>

    <van-pull-refresh v-model="refreshing" @refresh="onRefresh" class="van-hairline--top">
      <van-list v-model="loading" :finished="finished" finished-text="没有更多了" @load="onLoad">
        <div v-for="(device, index) in deviceData" :key="index" class="device van-hairline--bottom">
          <div class="device-item">
            <div class="device-item-text">
              <div class="device-item-content" style="margin-bottom: 6px">
                <div>
                  <div class="device-name">
                    <!-- <span class="device-name-icon">
                      <van-icon size="18" name="label" />
                    </span> -->
                    {{ device.name }}
                  </div>
                  <!-- <div class="device-code">
                  {{ device.code }}
                </div> -->
                </div>
                <div class="device-status">
                  <van-tag type="success" v-if="device.status == 1">正常
                  </van-tag>
                  <van-tag type="warning" v-if="device.status == 2">故障
                  </van-tag>
                  <van-tag type="danger" v-if="device.status == 3">报警
                  </van-tag>
                </div>
              </div>
              <div style="display: flex;align-items: flex-end;">
                <div @click="handleDetail(device)" class="device-content">
                  <p>
                    <span style="color:#333">所属区域：</span>{{ device.areaName }}
                  </p>
                  <p>
                    <span style="color:#333">产品名称：</span>{{ device.productName }}
                  </p>
                  <p>
                    <span style="color:#333">产品分类：</span>{{ device.address }}
                  </p>
                  <p>
                    <span style="color:#333">安装详细地址：</span>{{ device.address }}
                  </p>
                </div>
              </div>
            </div>

            <div class="device-Btn">
              <div @click="realBtn(device)" class="device-real">
                <van-icon size="8em" name="underway-o" />
                <span style="margin-left:4px"> 实时数据</span>
              </div>
              <div @click="alarmBtn(device)" class="device-alarm">
                <van-icon size="8em" name="bulb-o" />
                <span style="margin-left:4px">告警数据</span>
              </div>
            </div>
          </div>
        </div>
        <div class="van-list__placeholder"></div>
      </van-list>
    </van-pull-refresh>
    <van-popup position="right" :style="{ height: '100%', width: '100%' }" v-model="popupShow" class="popup">
      <van-nav-bar title="返回" left-arrow @click-left="reviseShowBack" />
      <div class="popup-content">
        <!-- <van-radio-group v-show="regionMast == 2" v-model="params.areaId">
          <van-radio
            v-for="(item, index) in regionChildren"
            :key="index"
            :name="item.id"
            >{{ item.name }}</van-radio
          >
        </van-radio-group> -->
        <van-radio-group v-show="regionMast == 3" v-model="params.productId">
          <van-radio v-for="(item, index) in treeChildrenData" :key="index" :name="item.id">{{ item.name }}
          </van-radio>
        </van-radio-group>
        <van-search v-show="regionMast == 1" v-model="params.name" shape="round" background="#fff"
          placeholder="请输入设备名称" />
        <span v-show="regionMast == 1" class="popup-label" slot="label">
          <span style="font-size:14px" class="tab-label active">重点设备:</span>
        </span>
        <van-radio-group v-show="regionMast == 1" v-model="params.important" direction="horizontal">
          <van-radio name="0">一般设备</van-radio>
          <van-radio name="1">重点设备</van-radio>
        </van-radio-group>
      </div>

      <div class="confirm-button" style="margin: 16px;">
        <van-button round block type="info" native-type="submit" @click="resetBtn" style="margin-right:10px">重置
        </van-button>
        <van-button round block type="info" native-type="submit" @click="confirmBtn">确认
        </van-button>
      </div>
    </van-popup>
  </div>
</template>

<script>
import equipmentManage from '@/api/device/equipmentManage.js'
import productManage from '@/api/device/productManage.js'
import req from '@/request.js'
import resourceManage from '@/api/device/resourceManage.js'
import equipmentIndex from '@/api/device/equipmentIndex.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import navBar from '../components/navBar.vue'

export default {
  components: {
    navBar
  },
  name: 'MobileDevice',
  data() {
    return {
      props: {
        label: 'name',
        children: 'children'
      },
      treeDataIds: '',
      regionMast: 1,
      regionId: '',
      regionTreeData: [],
      siftActive: '',
      popupShow: false,
      activeIds: '',
      activeChildrenIndex: 0,
      activeIndex: 0,
      policeList: [],
      treeData: [],
      treeChildrenData: [],
      queryParam: {
        pageBean: ''
      },
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'product_id_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'status',
          relation: 'AND',
          value: ''
        }
      ],
      page: 1,
      startPicker: false,
      statusList: [
        { text: '所有', value: '' },
        { text: '正常', value: '1' },
        { text: '故障', value: '2' },
        { text: '报警', value: '3' }
      ],
      statusData: { name: '', value: '' },
      title: '设备查询',
      currentUser: {},
      params: {
        name: '',
        productId: '', //产品
        status: '', //状态
        important: '', //重点设备
        areaId: '' //区域
      },
      previewUrl:
        window.context.portal + '/file/onlinePreviewController/v1/getFileById_', //图标预览
      columns: [], //产品列表
      startColumns: [],
      product: {
        name: '',
        id: ''
      },
      showPicker: false,
      deviceData: [],
      loading: false,
      finished: true,
      refreshing: false
    }
  },
  mounted() {
    this.currentUser = JSON.parse(sessionStorage.getItem('currentUser'))
    this.deviceStatus = dictUtils.getDictItemsFromCache('sbzt')
    // this.getProducts()
    if (this.$route.query.item) {
      console.log(1111111111)
      this.params.productId = this.$route.query.item.typeId
      this.page = 1
      this.deviceData = []
      this.getDevice()
    } else {
      this.getDevice()
    }
    this.getTreen()
    this.getAreaTree()
  },
  methods: {
    handleCheckChange(data, checked, tree) {
      console.log(data, checked)
      if (checked) {
        this.$refs.treeList.setCheckedNodes([data])
        this.params.areaId = data.id
        this.page = 1
        this.deviceData = []
        this.getDevice()
      }
      if (checked == false) {
        this.params.areaId = ''
        this.page = 1
        this.deviceData = []
        this.getDevice()
      }
    },
    handleNodeClick(data) {
      console.log(data)
    },
    loadNode(node, resolve) {
      if (node.level === 0) {
        return resolve([{ name: 'region1' }, { name: 'region2' }])
      }
      if (node.level > 3) return resolve([])

      var hasChild
      if (node.data.name === 'region1') {
        hasChild = true
      } else if (node.data.name === 'region2') {
        hasChild = false
      } else {
        hasChild = Math.random() > 0.5
      }

      setTimeout(() => {
        var data
        if (hasChild) {
          data = [
            {
              name: 'zone' + this.count++
            },
            {
              name: 'zone' + this.count++
            }
          ]
        } else {
          data = []
        }

        resolve(data)
      }, 500)
    },

    //返回
    reviseShowBack() {
      // this.params.areaId = ''
      // this.params.important = ''
      // this.params.name = ''
      this.popupShow = false
    },
    getAreaTree() {
      equipmentManage.loadAreaTree(
        {
          id: '0'
        },
        res => {
          console.log(res)
          this.regionTreeData = res.value
        }
      )
    },
    //重置
    resetBtn() {
      this.params.areaId = ''
      this.params.productId = ''
      this.params.name = ''
      this.params.important = ''
      this.page = 1
      this.deviceData = []
      this.getDevice()
      this.popupShow = false
    },
    //弹出框按钮
    confirmBtn() {
      this.page = 1
      this.deviceData = []
      this.getDevice()
      this.popupShow = false
    },
    //搜索
    seoBtn(v) {
      this.regionMast = 1
      // this.siftActive = '0'
      this.popupShow = true
    },
    // //重点单位
    // focusBtn() {
    //   this.siftActive = '1'
    //   this.popupShow = true
    // },
    //
    onClickLeft() {
      this.$router.go(-1)
    },
    //
    onNavClick(item) {
      console.log(item)
      if (item.children) {
        this.treeChildrenData = item.children
      } else {
        this.treeChildrenData = [
          {
            name: item.text,
            id: item.value
          }
        ]
      }
      this.regionMast = 3
      this.popupShow = true
    },
    onTtemClick(val) {
      this.page = 1
      this.params.productId = this.activeIds
      this.deviceData = []
      this.getDevice()

      this.$refs.item.toggle()
      // console.log(this.activeIds)
    },
    // 产品组织树查询
    getTreen() {
      productManage.getProductTree().then(res => {
        console.log(res)
        res.value.map(item => {
          item.children = item.children.map(items => {
            return {
              children: items.children,
              value: items.id,
              text: items.name
            }
          })
        })
        this.treeData = res.value.map(item => {
          return {
            children: item.children,
            value: item.id,
            text: item.name
          }
        })
        console.log(this.treeData)
        // this.$set(this.treeData)
      })
    },
    // 跳转实时
    realBtn(item) {
      this.$router.push({ name: 'RealtimeData', query: { item: item } })
    },
    // 跳转告警
    alarmBtn(item) {
      this.$router.push({ name: 'AlarmData', query: { item: item } })
    },
    // 跳转设备详情
    handleDetail(item) {
      this.$router.push({ name: 'DeviceDetail', query: { id: item.id } })
    },
    // startConfirm(data) {
    //   this.statusData.name = data.name
    //   // this.statusData.value = data.value
    //   this.querys[1].value = data.value
    //   this.startPicker = false
    //   this.deviceData = []
    //   this.page = 1
    //   this.getDevice()
    // },
    // onConfirm(data) {
    //   console.log(data)
    //   this.product.name = data.name
    //   // this.product.id = data.id
    //   this.querys[0].value = data.id
    //   this.showPicker = false
    //   this.deviceData = []
    //   this.page = 1
    //   this.getDevice()
    // },
    onCancel() {
      this.showPicker = false
    },
    onLoad() {
      // // this.loading = true
      // // this.getDevice()
      setTimeout(() => {
        this.loading = true
        this.getDevice()
      }, 500)
    },
    onRefresh() {
      setTimeout(() => {
        this.page = 1
        this.refreshing = true
        this.deviceData = []
        this.getDevice()
      }, 500)
    },
    teamChange(v) {
      this.page = 1
      // this.pageNo = 1
      this.deviceData = []
      this.getDevice()
    },
    orgChange(v) {
      this.page = 1
      this.deviceData = []
      this.getDevice()
    },
    getDevice() {
      this.finished = false
      this.queryParam.pageBean = { pageSize: 10, page: this.page }
      // this.loading = true
      this.queryParam.params = this.params
      this.queryParam.querys = []
      // if (this.querys[0].value) {
      //   this.queryParam.querys.push(this.querys[0])
      // }
      // if (this.querys[1].value) {
      //   this.queryParam.querys.push(this.querys[1])
      // }
      resourceManage.loadDevice(this.queryParam, res => {
        console.log(res, 'res')
        this.loading = false
        this.deviceData = this.deviceData.concat(res.rows)
        console.log(this.deviceData)
        this.page++
        // 如果加载完毕，显示没有更多了
        if (res.rows.length === 0) {
          this.finished = true
        }
        setTimeout(() => {
          //code
          this.refreshing = false
        }, 1000)
      })
    }
    // getProducts() {
    //   let url = window.context.portal + '/device/product/info/findAll'
    //   req.post(url, {}).then(res => {
    //     if (res.status == 200) {
    //       console.log(res)
    //       this.columns = res.data.map(item => {
    //         return {
    //           text: item.name,
    //           value: item.id
    //         }
    //       })
    //       this.columns[0] = {
    //         text: '请选择',
    //         value: ''
    //       }
    //     }
    //   })
    // }
  }
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';

::v-deep .device .device-item-text[data-v-3c48377e] {
  border-bottom: 0;
}

::v-deep .van-picker-column__item .van-ellipsis {
  font-size: 20px;
}

::v-deep .el-tree-node__content {
  height: 200px;

  .el-tree-node__expand-icon {
    font-size: 100px;
  }

  .el-tree-node__label {
    font-size: 50px;
    margin-left: 20px;
  }

  .el-checkbox__inner::after {
    width: 20px;
    height: 36px;
    left: 26px;
    top: 12px;
    // position: absolute;
    // top: 1px;
  }

  .el-checkbox__inner {
    border-radius: 40px;
    width: 80px;
    height: 80px;
  }
}

//  ::v-deep .van-dropdown-item__content {
//   min-height: 60%;
//   // position: relative;
//   // .van-button--round {
//   //   position: absolute;
//   //   bottom: 50px;
//   // }
// }
::v-deep .van-radio-group {
  display: flex;
  flex-wrap: wrap;

  .van-radio {
    width: 48%;
  }

  ::v-deep .van-radio__label,
  .van-checkbox__label {
    text-align: center;
    margin-left: 0;
    height: 330px;
    line-height: 330px;
    background-color: #f6f8fa;
    width: 100%;
  }

  // 去掉原本的勾选样式
  ::v-deep .van-radio__icon {
    border: 0;
    display: none;
  }

  // 选中之后的文字颜色和背景色设置
  .van-radio__icon--checked+.van-radio__label,
  .van-checkbox__icon--checked+.van-checkbox__label {
    color: #617af0;
    background-color: #ecf0ff;
  }
}

.van-radio {
  margin: 40px 0 0 30px;
}

.popup-content {
  height: 86%;
  overflow-y: scroll;
  padding: 50px;

  .popup-label {
    color: #666666;
  }
}

::v-deep .van-nav-bar .van-icon {
  color: white !important;
}

::v-deep .van-nav-bar__content {
  height: 9vw !important;
  background-color: #469ff7;

  .van-nav-bar__title {
    color: white;
  }
}

.van-sidebar-item--select::before {
  background-color: #469ff7;
}

.confirm-button {
  width: 90%;
  position: fixed;
  bottom: 20px;
  display: flex;
  justify-content: space-evenly;
}

.van-cell::after {
  border: 0;
}

.containter-sticky {
  width: 100%;
  position: fixed;
  top: 0;
  z-index: 100;
}

.van-cell__title span,
.van-cell__value span {
  font-size: 82px;
}

.van-cell__value span {
  color: $--mobile-text-active;
}

::v-deep .van-dropdown-menu__bar {
  box-shadow: 0 0px 0px rgba(255, 255, 255, 0.12);
}

.search-box {
  display: flex;
  width: 100%;
  z-index: 10;

  // padding-top: 200px;
  .van-dropdown-menu {
    width: 80%;
  }

  .van-search {
    flex: 1;
  }

  >.van-button {
    flex: 1;
    height: auto;
  }
}

.treeDataLeft {

  //修改左侧宽度
  .van-tree-select__nav {
    flex: 1 !important;
  }

  .van-tree-select__content {
    flex: 1.6 !important;
  }
}

.device {
  // background: #fff;
  background-color: #f9f9f9;
  // margin-bottom: 6px;
  padding: 40px 40px 0 40px;
  box-sizing: border-box;
  color: $--mobile-text-sub;
  // display: flex;
  // align-items: center;
  width: 100%;

  .device-Btn {
    display: flex;
    height: 180px;

    .device-real {
      flex: 1;
      display: flex;
      justify-content: center;
      align-items: center;
      height: 140px;
      text-align: center;
      color: #469ff7;
      font-size: 10px;
      border-right: 1px solid #f7f7f7;
      // margin-right: 40px;
    }

    .device-alarm {
      display: flex;
      justify-content: center;
      align-items: center;
      flex: 1;
      height: 140px;
      text-align: center;
      color: #ff7b50;
      font-size: 10px;
    }
  }

  .device-item {
    background-color: #fff;
    border-radius: 60px;
    border: 1px solid #f7f7f7 !important;
  }

  .device-content {
    width: 100%;
    // padding: 50px 0px 50px 0px;
    // height: 400px;
    font-size: 50px;

    p {
      margin: 10px 0 10px 0;
    }
  }

  .device-item-img {
    width: 256px;
    height: 256px;

    img {
      width: 100%;
      height: 100%;
    }
  }

  .device-item-text {
    padding: 20px 100px 20px 100px;
    // margin-left: 10px;
    // width: calc(100% - 256px - 10px);
    border-bottom: 1px solid #f7f7f7 !important;
  }

  .device-item-content {
    display: flex;
    justify-content: space-between;
    align-items: center;
    // align-items: flex-start;

    span {
      font-size: 60px;
    }
  }

  .device-name {
    font-size: 72px;
    color: $--mobile-text-main;
  }

  .device-name-icon {
    color: $-mobile-primary;
    margin-right: 2px;
  }

  .device-code {
    color: $--mobile-text-sub;
    font-size: 82px;
  }

  .device-item-title {
    color: #49a1f9;
    margin-right: 2px;
  }

  .device-status .van-tag {
    display: block;
    text-align: center;
    height: 80px;
    line-height: 80px;
    font-size: 60px;
    padding: 0 15px;
  }

  .van-tag {
    width: 200px;
    display: flex;
    justify-content: center;
  }
}
</style>
<style lang="scss">
@import '@/assets/css/vant-custom.scss';
</style>
